@@ -1,14 +1,14 @@
-from abc import abstractmethod
+from abc import abstractmethod, ABC
 from collections.abc import Mapping
-from typing import List
+from typing import List, Union, Iterable, Any
 
 
 class Box:
-    def __init__(self, *args, delimiter="\n"):
+    def __init__(self, *args: Union[str, "Box"], delimiter: str = "\n"):
         self._inner_object = [a for a in args if a]
         self.delimiter = delimiter
 
-    def _get_markdown(self, arg):
+    def _get_markdown(self, arg: Union[str, "Box"]) -> str:
         if hasattr(arg, 'to_markdown'):
             return arg.to_markdown()
         return arg
@@ -19,15 +19,15 @@ class Box:
         return self.delimiter.join([self._get_markdown(a) for a in self._inner_object])
 
 
-class CustomMapping(Mapping):
+class CustomMapping(Mapping[str, Any], ABC):
     def __len__(self) -> int:
         return len(self.fields)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterable[str]:
         for f in self.fields:
             yield f
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> Any:
         ret = getattr(self, key)
         if hasattr(ret, 'to_markdown'):
             return ret.to_markdown()
@@ -37,7 +37,3 @@ class CustomMapping(Mapping):
     @abstractmethod
     def fields(self) -> List[str]:
         pass
-
-
-
-
